package FPauth-core

  1. Overview
  2. Docs

Module FPauth_core.Auth_signSource

Auth_sign is a module containig signatures for modules which can be implemented and integrated from outside the lib, as well as signatures for some inner modules.

Sourcemodule type MODEL = sig ... end

MODEL is a signature for modules handling authenticable entities

Sourcemodule type SESSIONMANAGER = sig ... end

SESSIONMANAGER is a signature for a functor producing modules for controlling sessions and authentications of entities with type MODEL.t

Sourcemodule type STRATEGY = sig ... end

STRATEGY is a module which contains functions for entity authentications in a certain method, as well as supporting routes and functions

Sourcemodule type AUTHENTICATOR = sig ... end

AUTHENTICATOR is a signature for a functor to create authenticators of various entities over various strategies (See STRATEGY)

Sourcemodule type VARIABLES = sig ... end

VARIABLES is a module containing field variables based on MODEL

Sourcemodule type RESPONSES = sig ... end

RESPONSES is a module which defines how the library should represent some basic events

Sourcemodule type ROUTER = sig ... end

ROUTER is a module which contains handlers for authentication and creates routes for them.