Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Auth_sign.RESPONSESSourceRESPONSES is a module which defines how the library should represent some basic events
val login_successful : Dream.request -> Dream.response Dream.promiselogin_successful is triggered when authentication has been successful
val login_error : Dream.request -> Dream.response Dream.promiselogin_error is triggered if there was any kind of failure during authentication
val logout : Dream.request -> Dream.response Dream.promiselogout is triggered after authentication has been reset