Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Auth_sign.STRATEGYSourceSTRATEGY is a module which contains functions for entity authentications in a certain method, as well as supporting routes and functions
type entity is a type of authenticatable entity equal to MODEL.t
val call : Dream.request -> entity -> entity Static.StratResult.t Lwt.tcall is a core function of a strategy. It determines ways of authenticating an entity
val routes : Dream.routeroutes defines some additional routes to handlers of a strategy if they are needed. Can contain multiple routes using Dream.scope
val name : Base.stringname is a name of the STRATEGY. Used to define wether the strat can be applied to a certain entity.