package FPauth-core

  1. Overview
  2. Docs

Module Authenticator.MakeSource

Make creates an instance of Auth_sign.AUTHENTICATOR for a given model and variables

Parameters

module V : Auth_sign.VARIABLES with type entity = M.t

Signature

Sourcetype entity = M.t

type entity is a type of authenticatable entity equal to MODEL.t

Sourcetype strategy = (module Auth_sign.STRATEGY with type entity = entity)

strategy is a function that authenticates an entity from a request.

authenticate runs several authentication strategies for a request and defines, whether overall authentication was successful or not

logout invalidates session, which resets authentication status to false