Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Make_Auth.AuthenticatorSourceAuthenticator contains functions for running FPauth.Auth_sign.STRATEGY list and performing logouts
strategy is a function that authenticates an entity from a request.
authenticate runs several authentication strategies for a request and defines, whether overall authentication was successful or not
logout invalidates session, which resets authentication status to false