Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
FPauth_core.StaticSourceStatic is a module containg static type definitions, which are not dependent on Auth_sign.MODEL
Static is a module containing all FPauth features, which are not dependant on FPauth.Auth_sign.MODEL
StratResult defines results of strategies, as well as some helpful functions.
AuthResult is a result of full authentication process. Similar to StratResult, but doesn't have some types which are meaningful only for strategies. Authenticated and Rescue loose content as it is stored in Dream.field by the end of authentication