Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
FPauth_core.Auth_signSourceAuth_sign is a module containig signatures for modules which can be implemented and integrated from outside the lib, as well as signatures for some inner modules.
MODEL is a signature for modules handling authenticable entities
SESSIONMANAGER is a signature for a functor producing modules for controlling sessions and authentications of entities with type MODEL.t
STRATEGY is a module which contains functions for entity authentications in a certain method, as well as supporting routes and functions
AUTHENTICATOR is a signature for a functor to create authenticators of various entities over various strategies (See STRATEGY)
VARIABLES is a module containing field variables based on MODEL
RESPONSES is a module which defines how the library should represent some basic events